pub struct AutoChest {
pub active_filter: Option<AutoChestFilter>,
pub filters: Vec<AutoChestFilter>,
pub power_compare_enabled: bool,
pub batch_size: i64,
}Fields
active_filter: Option<AutoChestFilter>filters: Vec<AutoChestFilter>power_compare_enabled: boolbatch_size: i64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AutoChest
impl<'de> Deserialize<'de> for AutoChest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AutoChest
impl JsonSchema for AutoChest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for AutoChest
impl Tsify for AutoChest
const DECL: &'static str = "export interface AutoChest {\n active_filter: AutoChestFilter | null;\n filters: AutoChestFilter[];\n power_compare_enabled: boolean;\n batch_size: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for AutoChest
impl StructuralPartialEq for AutoChest